@@ -76,25 +76,25 @@ func TestInclusionTags(t *testing.T) {
 	doAssertExists()
 
 	// test default tags
-	p.KluctlMust("deploy", "--yes", "-t", "test", "-I", "cm1")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-I", "cm1")
 	doAssertExists("cm1")
-	p.KluctlMust("deploy", "--yes", "-t", "test", "-I", "cm2")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-I", "cm2")
 	doAssertExists("cm2")
 
 	// cm3/cm4 don't have default tags, so they should not deploy
-	p.KluctlMust("deploy", "--yes", "-t", "test", "-I", "cm3")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-I", "cm3")
 	doAssertExists()
 
 	// but with tag2, at least cm3 should deploy
-	p.KluctlMust("deploy", "--yes", "-t", "test", "-I", "tag2")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-I", "tag2")
 	doAssertExists("cm3")
 
 	// let's try 2 tags at once
-	p.KluctlMust("deploy", "--yes", "-t", "test", "-I", "tag3", "-I", "tag4")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-I", "tag3", "-I", "tag4")
 	doAssertExists("cm4", "cm5")
 
 	// And now let's try a tag that matches all non-default ones
-	p.KluctlMust("deploy", "--yes", "-t", "test", "-I", "tag3", "-I", "tag1")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-I", "tag3", "-I", "tag1")
 	doAssertExists("cm6", "cm7")
 }
 
@@ -110,15 +110,15 @@ func TestExclusionTags(t *testing.T) {
 	doAssertExists()
 
 	// Exclude everything except cm1
-	p.KluctlMust("deploy", "--yes", "-t", "test", "-E", "cm2", "-E", "tag1")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-E", "cm2", "-E", "tag1")
 	doAssertExists("cm1")
 
 	// Test that exclusion has precedence over inclusion
-	p.KluctlMust("deploy", "--yes", "-t", "test", "-E", "cm2", "-E", "tag1", "-I", "cm2")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-E", "cm2", "-E", "tag1", "-I", "cm2")
 	doAssertExists()
 
 	// Test that exclusion has precedence over inclusion
-	p.KluctlMust("deploy", "--yes", "-t", "test", "-I", "tag1", "-E", "tag6")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-I", "tag1", "-E", "tag6")
 	doAssertExists("cm3", "cm4", "cm5", "cm6")
 }
 
@@ -133,13 +133,13 @@ func TestInclusionIncludeDirs(t *testing.T) {
 
 	doAssertExists()
 
-	p.KluctlMust("deploy", "--yes", "-t", "test", "-I", "itag1")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-I", "itag1")
 	doAssertExists("icm1")
 
-	p.KluctlMust("deploy", "--yes", "-t", "test", "-I", "include2")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-I", "include2")
 	doAssertExists("icm2", "icm3")
 
-	p.KluctlMust("deploy", "--yes", "-t", "test", "-I", "itag5")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-I", "itag5")
 	doAssertExists("icm4", "icm5")
 }
 
@@ -154,13 +154,13 @@ func TestInclusionDeploymentDirs(t *testing.T) {
 
 	doAssertExists()
 
-	p.KluctlMust("deploy", "--yes", "-t", "test", "--include-deployment-dir", "include1/icm1")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "--include-deployment-dir", "include1/icm1")
 	doAssertExists("icm1")
 
-	p.KluctlMust("deploy", "--yes", "-t", "test", "--include-deployment-dir", "include2/icm3")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "--include-deployment-dir", "include2/icm3")
 	doAssertExists("icm3")
 
-	p.KluctlMust("deploy", "--yes", "-t", "test", "--exclude-deployment-dir", "include3/icm5")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "--exclude-deployment-dir", "include3/icm5")
 	var a []string
 	for _, x := range p.ListDeploymentItemPathes(".", false) {
 		if x != "icm5" {
@@ -181,25 +181,25 @@ func TestInclusionPrune(t *testing.T) {
 
 	doAssertExists(nil, nil)
 
-	p.KluctlMust("deploy", "--yes", "-t", "test")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test")
 	doAssertExists(p.ListDeploymentItemPathes(".", false), nil)
 
 	p.DeleteKustomizeDeployment("cm1")
-	p.KluctlMust("prune", "--yes", "-t", "test", "-I", "non-existent-tag")
+	p.KluctlMust(t, "prune", "--yes", "-t", "test", "-I", "non-existent-tag")
 	doAssertExists(nil, nil)
 
-	p.KluctlMust("prune", "--yes", "-t", "test", "-I", "cm1")
+	p.KluctlMust(t, "prune", "--yes", "-t", "test", "-I", "cm1")
 	doAssertExists(nil, []string{"cm1"})
 
 	p.DeleteKustomizeDeployment("cm2")
-	p.KluctlMust("prune", "--yes", "-t", "test", "-E", "cm2")
+	p.KluctlMust(t, "prune", "--yes", "-t", "test", "-E", "cm2")
 	doAssertExists(nil, nil)
 
 	p.DeleteKustomizeDeployment("cm3")
-	p.KluctlMust("prune", "--yes", "-t", "test", "--exclude-deployment-dir", "cm3")
+	p.KluctlMust(t, "prune", "--yes", "-t", "test", "--exclude-deployment-dir", "cm3")
 	doAssertExists(nil, []string{"cm2"})
 
-	p.KluctlMust("prune", "--yes", "-t", "test")
+	p.KluctlMust(t, "prune", "--yes", "-t", "test")
 	doAssertExists(nil, []string{"cm3"})
 }
 
@@ -212,16 +212,16 @@ func TestInclusionDelete(t *testing.T) {
 		assertExistsHelper(t, p, k, shouldExists, add, remove)
 	}
 
-	p.KluctlMust("deploy", "--yes", "-t", "test")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test")
 	doAssertExists(p.ListDeploymentItemPathes(".", false), nil)
 
-	p.KluctlMust("delete", "--yes", "-t", "test", "-I", "non-existent-tag")
+	p.KluctlMust(t, "delete", "--yes", "-t", "test", "-I", "non-existent-tag")
 	doAssertExists(nil, nil)
 
-	p.KluctlMust("delete", "--yes", "-t", "test", "-I", "cm1")
+	p.KluctlMust(t, "delete", "--yes", "-t", "test", "-I", "cm1")
 	doAssertExists(nil, []string{"cm1"})
 
-	p.KluctlMust("delete", "--yes", "-t", "test", "-E", "cm2")
+	p.KluctlMust(t, "delete", "--yes", "-t", "test", "-E", "cm2")
 	var a []string
 	for _, x := range p.ListDeploymentItemPathes(".", false) {
 		if x != "cm1" && x != "cm2" {
