@@ -2,12 +2,13 @@ package types
 
 import (
 	"encoding/json"
+	"github.com/kluctl/kluctl/lib/git/types"
 	"github.com/stretchr/testify/assert"
 	"testing"
 )
 
 func TestMarshaGitRefString(t *testing.T) {
-	var ref GitRef
+	var ref types.GitRef
 	err := json.Unmarshal([]byte(`"as_string"`), &ref)
 	assert.NoError(t, err)
 	assert.Equal(t, "as_string", ref.Ref)
@@ -19,14 +20,14 @@ func TestMarshaGitRefString(t *testing.T) {
 
 func TestMarshalGitRef(t *testing.T) {
 	s := `{"branch": "branch1"}`
-	var ref GitRef
+	var ref types.GitRef
 	err := json.Unmarshal([]byte(s), &ref)
 	assert.NoError(t, err)
 	assert.Equal(t, "branch1", ref.Branch)
 	assert.Empty(t, ref.Tag)
 
 	s = `{"tag": "tag1"}`
-	ref = GitRef{}
+	ref = types.GitRef{}
 	err = json.Unmarshal([]byte(s), &ref)
 	assert.NoError(t, err)
 	assert.Equal(t, "tag1", ref.Tag)
@@ -34,9 +35,9 @@ func TestMarshalGitRef(t *testing.T) {
 }
 
 func TestMarshalGitRefErrors(t *testing.T) {
-	err := json.Unmarshal([]byte(`{"branch": "branch1", "tag": "tag1"}`), &GitRef{})
+	err := json.Unmarshal([]byte(`{"branch": "branch1", "tag": "tag1"}`), &types.GitRef{})
 	assert.EqualError(t, err, "only one of the ref fields can be set")
 
-	err = json.Unmarshal([]byte(`{}`), &GitRef{})
+	err = json.Unmarshal([]byte(`{}`), &types.GitRef{})
 	assert.EqualError(t, err, "either branch, tag or commit must be set")
 }
