@@ -3,6 +3,7 @@ package uo
 import (
 	"fmt"
 	"github.com/ohler55/ojg/jp"
+	"reflect"
 	"regexp"
 	"strings"
 )
@@ -11,6 +12,21 @@ var isSimpleIdentifier = regexp.MustCompile(`^[A-Za-z_][A-Za-z0-9_]+$`)
 
 type KeyPath []interface{}
 
+func keyPathFromJsonPath(e jp.Expr) (KeyPath, error) {
+	ret := make(KeyPath, 0, len(e))
+	for _, f := range e {
+		switch tf := f.(type) {
+		case jp.Child:
+			ret = append(ret, string(tf))
+		case jp.Nth:
+			ret = append(ret, int(tf))
+		default:
+			return nil, fmt.Errorf("unsupported element in jsonpath: type=%s, path=%s", reflect.TypeOf(f).Name(), e.String())
+		}
+	}
+	return ret, nil
+}
+
 func (kl KeyPath) ToJsonPath() string {
 	p := ""
 	for _, k := range kl {
@@ -65,24 +81,15 @@ func NewMyJsonPathMust(p string) *MyJsonPath {
 }
 
 func (j *MyJsonPath) ListMatchingFields(o *UnstructuredObject) ([]KeyPath, error) {
-	var ret []KeyPath
-
-	o = o.Clone()
-	magic := struct{}{}
-
-	err := j.exp.Set(o.Object, magic)
-	if err != nil {
-		return nil, err
-	}
-
-	_ = o.NewIterator().IterateLeafs(func(it *ObjectIterator) error {
-		if it.Value() == magic {
-			var c []interface{}
-			c = append(c, it.KeyPath()...)
-			ret = append(ret, c)
+	l := j.exp.Locate(o.Object, 0)
+	ret := make([]KeyPath, 0, len(l))
+	for _, e := range l {
+		kp, err := keyPathFromJsonPath(e)
+		if err != nil {
+			return nil, err
 		}
-		return nil
-	})
+		ret = append(ret, kp)
+	}
 
 	return ret, nil
 }
@@ -116,7 +123,7 @@ func (j *MyJsonPath) GetFirstObject(o *UnstructuredObject) (*UnstructuredObject,
 	if !found {
 		return nil, false, nil
 	}
-	m, ok := x.(map[string]interface{})
+	m, ok := getDict(x)
 	if !ok {
 		return nil, false, fmt.Errorf("child is not a map")
 	}
@@ -128,13 +135,19 @@ func (j *MyJsonPath) GetFirstListOfObjects(o *UnstructuredObject) ([]*Unstructur
 	if !found {
 		return nil, false, nil
 	}
-	l, ok := x.([]interface{})
-	if !ok {
+	if x == nil {
+		// nil is a valid list of zero elements, so treat it as 'found'
+		return nil, true, nil
+	}
+	v := reflect.ValueOf(x)
+	if v.Type().Kind() != reflect.Slice {
 		return nil, false, fmt.Errorf("child is not a list")
 	}
+
 	var ret []*UnstructuredObject
-	for _, x := range l {
-		m, ok := x.(map[string]interface{})
+	for i := 0; i < v.Len(); i++ {
+		e := v.Index(i).Interface()
+		m, ok := getDict(e)
 		if !ok {
 			return nil, false, fmt.Errorf("child is not a list of maps")
 		}
@@ -150,3 +163,7 @@ func (j *MyJsonPath) Del(o *UnstructuredObject) error {
 func (j *MyJsonPath) Set(o *UnstructuredObject, v any) error {
 	return j.exp.Set(o.Object, v)
 }
+
+func (j *MyJsonPath) SetOne(o *UnstructuredObject, v any) error {
+	return j.exp.SetOne(o.Object, v)
+}
